# SYSZUXav
Python bindings for ffmpeg.
- SYSZUXav now only tested on Ubuntu 16.04/18.04.
- Other Linux distributions may work as well.


# Install
SYSZUXav has the dependency on ffmpeg library.
On Ubuntu 16.04/18.04:

```
apt update
apt install software-properties-common
add-apt-repository ppa:jonathonf/ffmpeg-4
apt update
apt install ffmpeg libavutil-dev libswresample-dev libavcodec-dev libavformat-dev
pip install syszuxav
```

# Usage
You can use SYSZUXav by simply import syszuxav:

```python
import cv2
import syszuxav                      
import numpy as np
#128 means decode thread number                 
v = syszuxav.SYSZUXav("gemfield.mp4", 128)
count = 0
while True:
  b = np.array(v.decodeJpg())
  if b.shape[0] == 0:
    continue
  cv2.imwrite("gemfield{}.jpg".format(count),b)
  count += 1
```

